@@ -11,7 +11,7 @@ class Kwik(Store):
 	"""
 	__parser = None
 
-	def __init__(self, parser=None):
+	def __init__(self, parser="html.parser"):
 		super().__init__()
 		self.__parser = parser
 
